@@ -4,9 +4,10 @@ from fabric.api import env, run
 from fabric.state import _AttributeDict
 
 class VirtualBoxTest(unittest.TestCase):
-    vm_name = 'Squeeze'
-    vbox_command = 'VBoxManage'
-    snapshot = 'fabtest-initial'
+    vm_name = 'Squeeze' # name or uuid of VirtualBox VM
+    vbox_command = 'VBoxManage'  # command to execute VBoxManage
+    snapshot = 'fabtest-initial' # snapshot to load before each test
+    keep_box = False # don't stop the VM after tests; useful for manual investigation
 
     # set this to False if snapshots are taken during tests
     # or if you want to be able to login to VM in a separate shell
@@ -17,7 +18,8 @@ class VirtualBoxTest(unittest.TestCase):
         self.activate_snapshot(self.snapshot)
 
     def tearDown(self):
-        self.box.stop()
+        if not self.keep_box:
+            self.box.stop()
 
     def activate_snapshot(self, name):
         assert self.box.snapshot_exists(name), 'Snapshot "%s" does not exist' % name
@@ -45,4 +47,3 @@ class FabTest(VirtualBoxTest):
         env.password = self.password
         env.key_filename = self.key_filename
         env.disable_known_hosts = True
-
